%The impact function computes the polygon's post impact velocities based on
%pre impact states.

function [vx1,vy1,w1] = impact(vx1o,vy1o,w1o,x1,y1,r1,vx2o,vy2o,w2o,e,u,inertia)

%coordinate axes are normal and tangential to contact surface

%vx1 - solving for this
%vy1 - solving for this

%B1 = 1/m1 + 1/m2 + y1^2/(m1r1^2) + y2^2/(m2r2^2)
%B2 = 1/m1 + 1/m2 + x1^2/(m1r1^2) + x2^2/(m2r2^2)
%B3 = x1y1/(m1r1^2) - x2y2/(m2r2^2)

%m2 = inf, r2 = inf
m1 = 1;

r1 = sqrt(inertia/m1);

B1 = 1/m1 + y1^2/(m1*r1^2);
B2 = 1/m1 + x1^2/(m1*r1^2);
B3 = x1*y1/(m1*r1^2);

vx1co = vx1o + w1o*y1;
vy1co = vy1o - w1o*x1;

%w2o = 0?
vx2co = vx2o;
vy2co = vy2o;

So = vx1co - vx2co;
Co = vy1co - vy2co;

%u = tan(alpha) -- what is alpha?

%ud = ((1+e)*B3*Co + B2*So)/((1+e)*B1*Co + B3*So);
%uq = (B3*Co + B2*So)/(B1*Co + B3*So);
us = -B3/B1;

%s = So/abs(So) if So ~=0
%s = 1 if So = 0

s = 1;
if So~=0
    s = So/abs(So);
end

Pd = (B2 + s*u*B3)*s*So;
Pq = (u*B1 + s*B3)*(-Co);

%if Pd > (1+e)Pq
    %sliding
%if Pq < Pd < (1+e)Pq
    %if u > abs(us)
        %R-sticking
    %if u < abs(us)
        %R-Reversed Sliding
%if Pd < Pq
    %if u > abs(us)
        %C-sticking
    %if u < abs(us)
        %C-Reversed Sliding
        
%if sliding
    %Px = -suPy
    %Py = -(1+e)(Co/(B2+suB3))
%if C-sticking
    %Px = (B3Py - So)/B1
    %Py = -(1+e)((B1Co + B3So)/(B1B2 - B3^2))
%if R-sticking
    %Px = (B3Py - So)/B1
    %Py = -(1+e)(Co/(B2 + suB3))
%if C-reversed sliding
    %Px = su(Py - (2So)/(B3 + suB1))
    %Py = -((1+e)/(B2 - suB3))(Co + 2suB3So/(B3 + suB1))
%if R-reversed sliding
    %Px = su(Py - (2So)/(B3 + suB1))
    %Py = -(1+e)(Co/(B2 + suB3))
    
%Add in B3=0 condition

if So==0
    if u < abs(us)
        %sliding
        Py = -(1+e)*(Co/(B2+s*u*B3));
        Px = -s*u*Py;
    else
        %sticking
        Py = -(1+e)*((B1*Co + B3*So)/(B1*B2 - B3^2));
        Px = (B3*Py - So)/B1;
    end
elseif Pd > (1+e)*Pq
    %sliding
    Py = -(1+e)*(Co/(B2+s*u*B3));
    Px = -s*u*Py;
elseif (Pq <= Pd) && (Pd <= (1+e)*Pq)
    if u >= abs(us)
        %R-sticking
        Py = -(1+e)*(Co/(B2 + s*u*B3));
        Px = (B3*Py - So)/B1;
    else %u < abs(us)
        %R-Reversed Sliding
        Py = -(1+e)*(Co/(B2 + s*u*B3));
        Px = s*u*(Py - (2*So)/(B3 + s*u*B1));
    end
elseif Pd < Pq
    if u >= abs(us)
        %C-sticking
        Py = -(1+e)*((B1*Co + B3*So)/(B1*B2 - B3^2));
        Px = (B3*Py - So)/B1;
    else %u < abs(us)
        %C-Reversed Sliding
        Py = -((1+e)/(B2 - s*u*B3))*(Co + 2*s*u*B3*So/(B3 + s*u*B1));
        Px = s*u*(Py - (2*So)/(B3 + s*u*B1));
    end
end
    
%use these eqns to change momentums into post-contact velocities
%Px = m1(vx1-vx1o)
%Py = m1(vy1-vy1o)
%Pxy1-Pyx1 = m1r1^2(w1-w1o)

vx1 = Px/m1 + vx1o;
vy1 = Py/m1 + vy1o;
w1 = (Px*y1 - Py*x1)/(m1*r1^2) + w1o;

%--theoretical eqns not necessary for program
%S = So + B1Px + B3Py
%C = Co - B3Px + B2Py
    
%vx1c = vx1 + w1y1
%vy1c = vy1 - w1x1