%Ian Gemp
%The movconstr function constructs a simulation movie using the contact
%states and system characteristics resulting from a previous "polysim"
%simulation.  The function returns the frames that compose the movie.

function F = movconstr(contstates,table,params,object)

table.xd = inline(char(diff(table.x)));
table.yd = inline(char(diff(table.y)));
table.phid = inline(char(diff(table.phi)));
table.x = inline(table.x);
table.y = inline(table.y);
table.phi = inline(table.phi);

g = -9.81;
thetad = contstates{2}(1).thetad;
xd = contstates{2}(1).xd;
y = contstates{2}(1).y;
yd = contstates{2}(1).yd;
nrg0 = -y*g+1/2*yd^2 + 1/2*xd^2 + 1/2*object.inertia*thetad^2;

movstates{1} = contstates{2}(1);
for ii=1:length(contstates{1})-1
    contact_time1 = contstates{1}(ii);
    contact_time2 = contstates{1}(ii+1);
    contact_state1 = contstates{2}(ii);
    newstates = datarecon(contact_time1,contact_time2,contact_state1,params.stepmov);
    for jj=1:length(newstates)
        movstates{end+1} = newstates{jj};
    end
end
F(1) = polyplot(table,params,movstates{1},object,nrg0,0);
for ii=1:length(movstates)-1
    F(end+1) = polyplot(table,params,movstates{ii+1},object,nrg0,params.stepmov*ii);
end

%use movie2avi to construct .avi file using frames