%Ian Gemp
%This function plots the polygon/table system at a specific time instant.

function frame = polyplot(table,params,state,object,nrg0,t)

%drawing variables

%table endpoints
slope = tan(table.phi(t));
xr = params.windim(2);
yr = slope*(params.windim(2)-table.x(t)) + table.y(t);
xl = params.windim(1);
yl = slope*(params.windim(1)-table.x(t)) + table.y(t);
tabendx = [xl table.x(t) xr];
tabendy = [yl table.y(t) yr];

%coordinate axes
%table
xdif = xr-xl;
ydif = params.windim(4)-params.windim(3);
mag = sqrt(1 + slope^2);
xtcoor = xl + .1*(xdif);
ytcoor = yl + .1*(xdif)*slope;
xtrt = xtcoor + .1*(xdif)*1/mag;
ytrt = ytcoor + .1*(xdif)*slope/mag;
xttp = xtcoor - .1*(ydif)*slope/mag;
yttp = ytcoor + .1*(ydif)*1/mag;
tabcoorx = [xttp xtcoor xtrt];
tabcoory = [yttp ytcoor ytrt];
%object
maxr = max(object.r);
xcen = state(1).x;
ycen = state(1).y;
xrt = xcen + maxr*cos(state(1).theta);
yrt = ycen + maxr*sin(state(1).theta);
xtp = xcen + maxr*cos(state(1).theta+pi/2);
ytp = ycen + maxr*sin(state(1).theta+pi/2);
objcoorx = [xtp xcen xrt];
objcoory = [ytp ycen yrt];
%skeleton structure
if object.nvert>1
    skeleton = zeros(object.nvert+1,2);
    for i=1:object.nvert
        skeleton(i,1) = object.r(i)*cos(state(1).theta + object.theta(i)) + state(1).x;
        skeleton(i,2) = object.r(i)*sin(state(1).theta + object.theta(i)) + state(1).y;
    end
    skeleton(object.nvert+1,:) = skeleton(1,:);
else
    [circtx,circty] = fplot(@(x) sqrt(object.r^2-(x-state(1).x)^2) + state(1).y,[state(1).x-object.r,state(1).x+object.r]);
    [circbx,circby] = fplot(@(x) -sqrt(object.r^2-(x-state(1).x)^2) + state(1).y,[state(1).x-object.r,state(1).x+object.r]);
    circtempx=0;
    circtempy=0;
    for i=1:length(circbx)
        circtempx(i,1)=circbx(end-(i-1),1);
        circtempy(i,1)=circby(end-(i-1),1);
    end
    circbx = circtempx;
    circby = circtempy;
    circx = [circtx;circbx];
    circy = [circty;circby];
end
%
%plotting
%energy
g = -9.81;
pot = -state(1).y*g;
kin = 1/2*state(1).yd^2 + 1/2*state(1).xd^2 + 1/2*object.inertia*state(1).thetad^2;
nrg = pot + kin;
energy = [nrg,pot,kin];
if t==0
    if object.nvert>1
        subplot(1,4,1:3),plot(state(1).x,state(1).y,'*','XdataSource','state(1).x','YDataSource','state(1).y');
        hold on
        plot(skeleton(:,1),skeleton(:,2),'g','XdataSource','skeleton(:,1)','YDataSource','skeleton(:,2)');
        plot(tabendx,tabendy,'- x r','XdataSource','tabendx','YDataSource','tabendy');
        plot(tabcoorx,tabcoory,'b','XdataSource','tabcoorx','YDataSource','tabcoory');
        plot(objcoorx,objcoory,'b','XdataSource','objcoorx','YDataSource','objcoory');
        axis(params.windim)
        axis square
        hold off
        subplot(1,4,4),bar(energy,'c','YDataSource','energy');
        set(gca,'XTickLabel',{'TOT','POT','KIN'});
        axis([0 4 0 1.1*nrg0]);
    else
        subplot(1,4,1:3),plot(state(1).x,state(1).y,'*','XdataSource','state(1).x','YDataSource','state(1).y');
        hold on
        plot(circx,circy,'g','XDataSource','circx','YDataSource','circy');
        plot(tabendx,tabendy,'- x r','XdataSource','tabendx','YDataSource','tabendy');
        plot(tabcoorx,tabcoory,'b','XdataSource','tabcoorx','YDataSource','tabcoory');
        plot(objcoorx,objcoory,'b','XdataSource','objcoorx','YDataSource','objcoory');
        axis(params.windim)
        axis square
        hold off
        subplot(1,4,4),bar(energy,'c','YDataSource','energy');
        set(gca,'XTickLabel',{'TOT','POT','KIN'});
        axis([0 4 0 1.1*nrg0]);
    end
else
    refreshdata(gcf,'caller')
end
frame = getframe(gcf);